==> deepin-font-manager_5.9.6.orig.tar.xz: deepin-font-manager-5.9.6/translations/deepin-font-manager_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Všechna písma</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivní</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>čínština</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Všechny znaky stejně široké</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou smazána</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou zapnuta</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou vypnuta</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Zakázat</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Použít na všechny vybrané rodiny písma</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Nainstalována stejná verze</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Písmo Systému</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Nainstalováno %1 písmo</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Nainstalováno %1 písem</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Toto písmo nebude dostupné aplikacím</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Tato písma nebude dostupná aplikacím</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Dalších %1 systémových písem není možné smazat</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Písmo „%1“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Dalších %1 systémových písem a písmo „%2“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Opravdu chcete %1 písem smazat?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Mazání písem – čekejte prosím…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Ověření písma</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Žádná písma k instalaci</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Pokračovat</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Nedovolte svým snům zůstat pouze sny</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Úplný název</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PostScript název</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Registrovaná obchodní značka</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Správa písem</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Správa písem pomáhá uživatelům instalovat a spravovat písma.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Načítání písem – čekejte prosím…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Písmo exportováno na vaši plochu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 písem exportováno na vaši plochu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat 1 písmo. Není dost volného místa na disku.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat %1 písem. Není dost volného místa na disku.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>vypnuto</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Písma byla deaktivována</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 je využíváno, takže ho nyní nelze zakázat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Systémová písma a ta, které jsou právě využívány, není možné smazat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Systémová písma není možné zakázat</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Ověřování…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nenainstalováno</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Žádné výsledky hledání</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Žádná písma</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>O stránku nahoru</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>O stránku dolů</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informace o písmu</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Zadejte náhledový text</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.13.orig.tar.xz: deepin-font-manager-5.9.13/translations/deepin-font-manager_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Všechna písma</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktivní</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>čínština</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Všechny znaky stejně široké</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou smazána</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou zapnuta</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou vypnuta</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Zakázat</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Použít na všechny vybrané rodiny písma</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Nainstalována stejná verze</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Písmo Systému</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>Nainstalováno %1 písmo</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>Nainstalováno %1 písem</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Nepodařilo se nainstalovat %1 písem. Není dost volného místa na disku</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Toto písmo nebude dostupné aplikacím</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Tato písma nebude dostupná aplikacím</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Dalších %1 systémových písem není možné smazat</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>Písmo „%1“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>Dalších %1 systémových písem a písmo „%2“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Opravdu chcete %1 písem smazat?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Mazání písem – čekejte prosím…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Ověření písma</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Žádná písma k instalaci</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Pokračovat</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Úplný název</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PostScript název</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Registrovaná obchodní značka</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Správa písem</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Správa písem pomáhá uživatelům instalovat a spravovat písma.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Načítání písem – čekejte prosím…</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Písmo exportováno na vaši plochu</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 písem exportováno na vaši plochu</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat 1 písmo. Není dost volného místa na disku.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat %1 písem. Není dost volného místa na disku.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>vypnuto</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Písma byla deaktivována</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 je využíváno, takže ho nyní nelze zakázat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Systémová písma a ta, které jsou právě využívány, není možné smazat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Systémová písma není možné zakázat</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Ověřování…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nenainstalováno</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Žádné výsledky hledání</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Žádná písma</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>O stránku nahoru</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>O stránku dolů</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informace o písmu</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Zadejte náhledový text</translation>
    </message>
</context>
</TS>
